@@ -19,6 +19,8 @@
 #ifndef INCLUDED_EFFECTS_H
 #define INCLUDED_EFFECTS_H
 
+#include "object.h"
+
 /* Types of effect */
 typedef enum
 {
@@ -29,13 +31,6 @@ typedef enum
 	EF_MAX
 } effect_index;
 
-struct effect {
-	struct effect *next;
-	u16b index;		/**< The effect index */
-	dice_t *dice;	/**< Dice expression used in the effect */
-	int params[3];	/**< Extra parameters to be passed to the handler */
-};
-
 /*** Functions ***/
 
 bool remove_all_curse(void);
@@ -47,7 +42,8 @@ const char *effect_info(struct effect *effect);
 const char *effect_desc(struct effect *effect);
 effect_index effect_lookup(const char *name);
 int effect_param(int index, const char *type);
-bool effect_do(struct effect *effect, bool *ident, bool aware, int dir, int beam, int boost);
+bool effect_do(struct effect *effect, struct object *obj, bool *ident,
+			   bool aware, int dir, int beam, int boost);
 void effect_simple(int index, const char* dice_string, int p1, int p2, int p3, bool *ident);
 
 #endif /* INCLUDED_EFFECTS_H */
