@@ -18,6 +18,7 @@
 
 #include "angband.h"
 #include "cave.h"
+#include "effects.h"
 #include "mon-desc.h"
 #include "mon-lore.h"
 #include "mon-make.h"
@@ -759,13 +760,6 @@ static const project_monster_handler_f monster_handlers[] = {
 	NULL
 };
 
-/*
- * Mega-Hack -- track "affected" monsters (see "project()" comments)
- */
-int project_m_n;
-int project_m_x;
-int project_m_y;
-
 
 /**
  * Deal damage to a monster from another monster.
@@ -804,12 +798,12 @@ static bool project_m_monster_attack(project_monster_handler_context_t *context,
 	/* Hurt the monster */
 	mon->hp -= dam;
 
-	/* Dead monster */
+	/* Dead or damaged monster */
 	if (mon->hp < 0) {
 		/* Give detailed messages if destroyed */
 		if (!seen) die_msg = MON_MSG_MORIA_DEATH;
 
-		/* dump the note*/
+		/* Death message */
 		add_monster_message(m_name, mon, die_msg, FALSE);
 
 		/* Generate treasure, etc */
@@ -819,7 +813,7 @@ static bool project_m_monster_attack(project_monster_handler_context_t *context,
 		delete_monster_idx(m_idx);
 
 		mon_died = TRUE;
-	} else if (!is_mimicking(mon)) { /* Damaged monster */
+	} else if (!is_mimicking(mon)) {
 		/* Give detailed messages if visible or destroyed */
 		if ((hurt_msg != MON_MSG_NONE) && seen)
 			add_monster_message(m_name, mon, hurt_msg, FALSE);
@@ -853,10 +847,12 @@ static bool project_m_player_attack(project_monster_handler_context_t *context,
 	struct monster *mon = context->mon;
 
 	/*
-	 * The monster is going to be killed, so display a specific death message
-	 * before mon_take_hit() displays its own message that the player has
-	 * killed/destroyed the monster. If the monster is not visible to
-	 * the player, use a generic message.
+	 * The monster is going to be killed, so display a specific death message.
+	 * If the monster is not visible to the player, use a generic message.
+	 *
+	 * Note that mon_take_hit() below is passed a zero-length string, which
+	 * ensures it doesn't print any death message and allows correct ordering
+	 * of messages.
 	 */
 	if (dam > mon->hp) {
 		if (!seen) die_msg = MON_MSG_MORIA_DEATH;
@@ -1039,7 +1035,8 @@ static void project_m_apply_side_effects(project_monster_handler_context_t *cont
  *
  * Hack -- effects on grids which are memorized but not in view are also seen.
  */
-bool project_m(int who, int r, int y, int x, int dam, int typ, int flg)
+void project_m(int who, int r, int y, int x, int dam, int typ, int flg,
+               bool *did_hit, bool *was_obvious)
 {
 	struct monster *mon;
 	struct monster_lore *lore;
@@ -1082,14 +1079,17 @@ bool project_m(int who, int r, int y, int x, int dam, int typ, int flg)
 		{0, 0, 0, 0, 0, 0},
 	};
 
+	*did_hit = FALSE;
+	*was_obvious = FALSE;
+
 	/* Walls protect monsters */
-	if (!square_isprojectable(cave, y,x)) return (FALSE);
+	if (!square_isprojectable(cave, y,x)) return;
 
 	/* No monster here */
-	if (!(m_idx > 0)) return (FALSE);
+	if (!(m_idx > 0)) return;
 
 	/* Never affect projector */
-	if (m_idx == who) return (FALSE);
+	if (m_idx == who) return;
 
 	/* Obtain monster info */
 	mon = cave_monster(cave, m_idx);
@@ -1110,7 +1110,7 @@ bool project_m(int who, int r, int y, int x, int dam, int typ, int flg)
 
 		/* Skip monsters with the same race */
 		if (caster->race == mon->race)
-			return (FALSE);
+			return;
 	}
 
 	/* Get monster name and possessive here, in case of polymorphing. */
@@ -1132,11 +1132,7 @@ bool project_m(int who, int r, int y, int x, int dam, int typ, int flg)
 	obvious = context.obvious;
 
 	/* Absolutely no effect */
-	if (context.skipped) return (FALSE);
-
-	/* Extract method of death, if the monster will be killed. */
-	if (dam > mon->hp)
-		context.hurt_msg = context.die_msg;
+	if (context.skipped) return;
 
 	/* Apply damage to the monster, based on who did the damage. */
 	if (who > 0)
@@ -1152,18 +1148,14 @@ bool project_m(int who, int r, int y, int x, int dam, int typ, int flg)
 	mon = context.mon;
 	obvious = context.obvious;
 
-	/* Verify this code XXX XXX XXX */
 	/* Check for NULL, since polymorph can occasionally return NULL. */
 	if (mon != NULL) {
 		/* Update the monster */
-		if (!mon_died) update_mon(mon, cave, FALSE);
+		if (!mon_died)
+			update_mon(mon, cave, FALSE);
 
-		/* Hack -- get new location in case of teleport */
-		y = mon->fy;
-		x = mon->fx;
-
-		/* Redraw the monster grid */
-		square_light_spot(cave, y, x);
+		/* Redraw the (possibly new) monster grid */
+		square_light_spot(cave, mon->fy, mon->fx);
 
 		/* Update monster recall window */
 		if (player->upkeep->monster_race == mon->race) {
@@ -1173,11 +1165,9 @@ bool project_m(int who, int r, int y, int x, int dam, int typ, int flg)
 	}
 
 	/* Track it */
-	project_m_n++;
-	project_m_x = x;
-	project_m_y = y;
+	*did_hit = true;
 
 	/* Return "Anything seen?" */
-	return (obvious);
+	*was_obvious = !!obvious;
 }
 
