@@ -1,6 +1,6 @@
-/*
- * File: savefile.c
- * Purpose: Savefile loading and saving main routines
+/**
+ * \file savefile.c
+ * \brief Savefile loading and saving main routines
  *
  * Copyright (c) 2009 Andi Sidwell <andi@takkaria.org>
  *
@@ -17,6 +17,8 @@
  */
 #include <errno.h>
 #include "angband.h"
+#include "game-world.h"
+#include "init.h"
 #include "savefile.h"
 
 /**
@@ -67,7 +69,9 @@
  */
 
 
-/** Magic bits at beginning of savefile */
+/**
+ * Magic bits at beginning of savefile
+ */
 static const byte savefile_magic[4] = { 83, 97, 118, 101 };
 static const byte savefile_name[4] = "VNLA";
 
@@ -86,7 +90,9 @@ struct blockinfo {
 	u32b version;
 };
 
-/** Savefile saving functions */
+/**
+ * Savefile saving functions
+ */
 static const struct {
 	char name[16];
 	void (*save)(void);
@@ -94,68 +100,51 @@ static const struct {
 } savers[] = {
 	{ "description", wr_description, 1 },
 	{ "rng", wr_randomizer, 1 },
-	{ "options", wr_options, 2 },
+	{ "options", wr_options, 1 },
 	{ "messages", wr_messages, 1 },
-	{ "monster memory", wr_monster_memory, 3 },
-	{ "object memory", wr_object_memory, 2 },
+	{ "monster memory", wr_monster_memory, 1 },
+	{ "object memory", wr_object_memory, 1 },
 	{ "quests", wr_quests, 1 },
-	{ "artifacts", wr_artifacts, 2 },
-	{ "player", wr_player, 3 },
-	{ "squelch", wr_squelch, 1 },
-	{ "misc", wr_misc, 2 },
+	{ "artifacts", wr_artifacts, 1 },
+	{ "player", wr_player, 1 },
+	{ "ignore", wr_ignore, 1 },
+	{ "misc", wr_misc, 1 },
 	{ "player hp", wr_player_hp, 1 },
 	{ "player spells", wr_player_spells, 1 },
-	{ "inventory", wr_inventory, 6 },
-	{ "stores", wr_stores, 6 },
+	{ "gear", wr_gear, 1 },
+	{ "stores", wr_stores, 1 },
 	{ "dungeon", wr_dungeon, 1 },
-	{ "objects", wr_objects, 6 },
-	{ "monsters", wr_monsters, 7 },
-	{ "ghost", wr_ghost, 1 },
+	{ "objects", wr_objects, 1 },
+	{ "monsters", wr_monsters, 1 },
+	{ "traps", wr_traps, 1 },
+	{ "chunks", wr_chunks, 1 },
 	{ "history", wr_history, 1 },
 };
 
-/** Savefile loading functions */
+/**
+ * Savefile loading functions
+ */
 static const struct blockinfo loaders[] = {
 	{ "description", rd_null, 1 },
-	{ "ghost", rd_null, 1 },
-	{ "randarts", rd_null, 3 },
 	{ "rng", rd_randomizer, 1 },
-	{ "options", rd_options_2, 2 },
+	{ "options", rd_options, 1 },
 	{ "messages", rd_messages, 1 },
-	{ "monster memory", rd_monster_memory_2, 2 },
-	{ "monster memory", rd_monster_memory_3, 3 },
-	{ "object memory", rd_object_memory_1, 1 },
-	{ "object memory", rd_object_memory_2, 2 },
+	{ "monster memory", rd_monster_memory, 1 },
+	{ "object memory", rd_object_memory, 1 },
 	{ "quests", rd_quests, 1 },
-	{ "artifacts", rd_artifacts, 2 },
-	{ "player", rd_player_2, 2 },
-	{ "player", rd_player_3, 3 },
-	{ "squelch", rd_squelch, 1 },
+	{ "artifacts", rd_artifacts, 1 },
+	{ "player", rd_player, 1 },
+	{ "ignore", rd_ignore, 1 },
 	{ "misc", rd_misc, 1 },
-	{ "misc", rd_misc_2, 2},
 	{ "player hp", rd_player_hp, 1 },
 	{ "player spells", rd_player_spells, 1 },
-	{ "inventory", rd_inventory_1, 1 },
-	{ "inventory", rd_inventory_2, 2 },
-	{ "inventory", rd_inventory_3, 3 },
-	{ "inventory", rd_inventory_4, 4 },	
-	{ "inventory", rd_inventory_5, 5 },	
-	{ "inventory", rd_inventory_6, 6 },	
-	{ "stores", rd_stores_1, 1 },
-	{ "stores", rd_stores_2, 2 },
-	{ "stores", rd_stores_3, 3 },
-	{ "stores", rd_stores_4, 4 },	
-	{ "stores", rd_stores_5, 5 },	
-	{ "stores", rd_stores_6, 6 },	
+	{ "gear", rd_gear, 1 },	
+	{ "stores", rd_stores, 1 },	
 	{ "dungeon", rd_dungeon, 1 },
-	{ "objects", rd_objects_1, 1 },
-	{ "objects", rd_objects_2, 2 },
-	{ "objects", rd_objects_3, 3 },
-	{ "objects", rd_objects_4, 4 },
-	{ "objects", rd_objects_5, 5 },	
-	{ "objects", rd_objects_6, 6 },	
-	{ "monsters", rd_monsters_6, 6 },
-	{ "monsters", rd_monsters_7, 7 },
+	{ "objects", rd_objects, 1 },	
+	{ "monsters", rd_monsters, 1 },
+	{ "traps", rd_traps, 1 },
+	{ "chunks", rd_chunks, 1 },
 	{ "history", rd_history, 1 },
 };
 
@@ -172,33 +161,25 @@ static u32b buffer_check;
 #define SAVEFILE_HEAD_SIZE		28
 
 
-/** Utility **/
+/**
+ * ------------------------------------------------------------------------
+ * Utility
+ * ------------------------------------------------------------------------ */
 
 
-/*
- * Hack -- Show information on the screen, one line at a time.
- *
- * Avoid the top two lines, to avoid interference with "note()".
+/**
+ * Tell the UI something about loading the game.
  */
 void note(const char *message)
 {
-	static int y = 2;
-
-	/* Draw the message */
-	prt(message, y, 0);
-	pause_line(Term);
-
-	/* Advance one line (wrap if needed) */
-	if (++y >= 24) y = 2;
-
-	/* Flush it */
-	Term_fresh();
+	event_signal_message(EVENT_INITSTATUS, MSG_BIRTH, message);
 }
 
 
-
-
-/** Base put/get **/
+/**
+ * ------------------------------------------------------------------------
+ * Base put/get
+ * ------------------------------------------------------------------------ */
 
 static void sf_put(byte v)
 {
@@ -219,9 +200,8 @@ static void sf_put(byte v)
 
 static byte sf_get(void)
 {
-	assert(buffer != NULL);
-	assert(buffer_size > 0);
-	assert(buffer_pos < buffer_size);
+	if ((buffer == NULL) || (buffer_size <= 0) || (buffer_pos >= buffer_size))
+		quit("Broken savefile - probably from a development version");
 
 	buffer_check += buffer[buffer_pos];
 
@@ -229,7 +209,10 @@ static byte sf_get(void)
 }
 
 
-/* accessor */
+/**
+ * ------------------------------------------------------------------------
+ * Accessor functions
+ * ------------------------------------------------------------------------ */
 
 void wr_byte(byte v)
 {
@@ -305,8 +288,7 @@ void rd_string(char *str, int max)
 	byte tmp8u;
 	int i = 0;
 
-	do
-	{
+	do {
 		rd_byte(&tmp8u);
 
 		if (i < max) str[i] = tmp8u;
@@ -328,7 +310,11 @@ void pad_bytes(int n)
 }
 
 
-/*** Savefile saving functions ***/
+/**
+ * ------------------------------------------------------------------------
+ * Savefile saving functions
+ * ------------------------------------------------------------------------ */
+
 
 static bool try_save(ang_file *file)
 {
@@ -339,8 +325,7 @@ static bool try_save(ang_file *file)
 	buffer = mem_alloc(BUFFER_INITIAL_SIZE);
 	buffer_size = BUFFER_INITIAL_SIZE;
 
-	for (i = 0; i < N_ELEMENTS(savers); i++)
-	{
+	for (i = 0; i < N_ELEMENTS(savers); i++) {
 		buffer_pos = 0;
 		buffer_check = 0;
 
@@ -378,29 +363,7 @@ static bool try_save(ang_file *file)
 	return TRUE;
 }
 
-/*
- * Set the savefile name.
- */
-void savefile_set_name(const char *fname)
-{
-	char path[128];
-
-#if defined(SETGID)
-	/* Rename the savefile, using the player_uid and base_name */
-	strnfmt(path, sizeof(path), "%d.%s", player_uid, fname);
-#else
-	/* Rename the savefile, using the base name */
-	strnfmt(path, sizeof(path), "%s", fname);
-#endif
-
-	/* Save the path */
-	path_build(savefile, sizeof(savefile), ANGBAND_DIR_SAVE, path);
-}
-
-
-
-
-/*
+/**
  * Attempt to save the player in a savefile
  */
 bool savefile_save(const char *path)
@@ -411,29 +374,26 @@ bool savefile_save(const char *path)
 	char old_savefile[1024];
 
 	/* New savefile */
-	strnfmt(old_savefile, sizeof(old_savefile), "%s%u.old", path,Rand_simple(1000000));
-	while (file_exists(old_savefile) && (count++ < 100)) {
-		strnfmt(old_savefile, sizeof(old_savefile), "%s%u%u.old", path,Rand_simple(1000000),count);
-	}
-	count = 0;
+	strnfmt(old_savefile, sizeof(old_savefile), "%s%u.old", path,
+			Rand_simple(1000000));
+	while (file_exists(old_savefile) && (count++ < 100))
+		strnfmt(old_savefile, sizeof(old_savefile), "%s%u%u.old", path,
+				Rand_simple(1000000),count);
 
-	/* Make sure that the savefile doesn't already exist */
-	/*safe_setuid_grab();
-	file_delete(new_savefile);
-	file_delete(old_savefile);
-	safe_setuid_drop();*/
+	count = 0;
 
 	/* Open the savefile */
 	safe_setuid_grab();
-	strnfmt(new_savefile, sizeof(new_savefile), "%s%u.new", path,Rand_simple(1000000));
-	while (file_exists(new_savefile) && (count++ < 100)) {
-		strnfmt(new_savefile, sizeof(new_savefile), "%s%u%u.new", path,Rand_simple(1000000),count);
-	}
+	strnfmt(new_savefile, sizeof(new_savefile), "%s%u.new", path,
+			Rand_simple(1000000));
+	while (file_exists(new_savefile) && (count++ < 100))
+		strnfmt(new_savefile, sizeof(new_savefile), "%s%u%u.new", path,
+				Rand_simple(1000000),count);
+
 	file = file_open(new_savefile, MODE_WRITE, FTYPE_SAVE);
 	safe_setuid_drop();
 
-	if (file)
-	{
+	if (file) {
 		file_write(file, (char *) &savefile_magic, 4);
 		file_write(file, (char *) &savefile_name, 4);
 
@@ -441,22 +401,20 @@ bool savefile_save(const char *path)
 		file_close(file);
 	}
 
-	if (character_saved)
-	{
+	if (character_saved) {
 		bool err = FALSE;
 
 		safe_setuid_grab();
 
-		if (file_exists(savefile) && !file_move(savefile, old_savefile))
+		if (file_exists(path) && !file_move(path, old_savefile))
 			err = TRUE;
 
-		if (!err)
-		{
-			if (!file_move(new_savefile, savefile))
+		if (!err) {
+			if (!file_move(new_savefile, path))
 				err = TRUE;
 
 			if (err)
-				file_move(old_savefile, savefile);
+				file_move(old_savefile, path);
 			else
 				file_delete(old_savefile);
 		} 
@@ -467,9 +425,8 @@ bool savefile_save(const char *path)
 	}
 
 	/* Delete temp file if the save failed */
-	if (file)
-	{
-		/* file is no longer valid, but it still points to a non zero
+	if (file) {
+		/* File is no longer valid, but it still points to a non zero
 		 * value if the file was created above */
 		safe_setuid_grab();
 		file_delete(new_savefile);
@@ -480,9 +437,14 @@ bool savefile_save(const char *path)
 
 
 
-/*** Savefile loading functions ***/
+/**
+ * ------------------------------------------------------------------------
+ * Savefile loading functions
+ * ------------------------------------------------------------------------ */
 
-/* Check the savefile header file clearly inicates that it's a savefile */
+/**
+ * Check the savefile header file clearly inicates that it's a savefile
+ */
 static bool check_header(ang_file *f) {
 	byte head[8];
 
@@ -494,7 +456,9 @@ static bool check_header(ang_file *f) {
 	return FALSE;
 }
 
-/* Get the next block header from the savefile */
+/**
+ * Get the next block header from the savefile
+ */
 static errr next_blockheader(ang_file *f, struct blockheader *b) {
 	byte savefile_head[SAVEFILE_HEAD_SIZE];
 	size_t len;
@@ -517,15 +481,19 @@ static errr next_blockheader(ang_file *f, struct blockheader *b) {
 	b->version = RECONSTRUCT_U32B(16);
 	b->size = RECONSTRUCT_U32B(20);
 
-	/* pad to 4 bytes */
+	/* Pad to 4 bytes */
 	if (b->size % 4)
 		b->size += 4 - (b->size % 4);
 
 	return 0;
 }
 
-/* Find the right loader for this block, return it */
-static loader_t find_loader(struct blockheader *b, const struct blockinfo *loaders) {
+/**
+ * Find the right loader for this block, return it
+ */
+static loader_t find_loader(struct blockheader *b,
+							const struct blockinfo *loaders)
+{
 	size_t i = 0;
 
 	/* Find the right loader */
@@ -539,8 +507,11 @@ static loader_t find_loader(struct blockheader *b, const struct blockinfo *loade
 	return NULL;
 }
 
-/* Load a given block with the given loader */
-static bool load_block(ang_file *f, struct blockheader *b, loader_t loader) {
+/**
+ * Load a given block with the given loader
+ */
+static bool load_block(ang_file *f, struct blockheader *b, loader_t loader)
+{
 	/* Allocate space for the buffer */
 	buffer = mem_alloc(b->size);
 	buffer_pos = 0;
@@ -557,13 +528,19 @@ static bool load_block(ang_file *f, struct blockheader *b, loader_t loader) {
 	return TRUE;
 }
 
-/* Skip a block */
-static void skip_block(ang_file *f, struct blockheader *b) {
+/**
+ * Skip a block
+ */
+static void skip_block(ang_file *f, struct blockheader *b)
+{
 	file_skip(f, b->size);
 }
 
-/* Try to load a savefile */
-static bool try_load(ang_file *f, const struct blockinfo *loaders) {
+/**
+ * Try to load a savefile
+ */
+static bool try_load(ang_file *f, const struct blockinfo *loaders)
+{
 	struct blockheader b;
 	errr err;
 
@@ -592,10 +569,6 @@ static bool try_load(ang_file *f, const struct blockinfo *loaders) {
 		return FALSE;
 	}
 
-	/* XXX Reset cause of death */
-	if (p_ptr->chp >= 0)
-		my_strcpy(p_ptr->died_from, "(alive and well)", sizeof(p_ptr->died_from));
-
 	return TRUE;
 }
 
@@ -611,7 +584,6 @@ static int get_desc(void) {
  * Try to get the 'description' block from a savefile.  Fail gracefully.
  */
 const char *savefile_get_description(const char *path) {
-	errr err;
 	struct blockheader b;
 
 	ang_file *f = file_open(path, MODE_READ, FTYPE_TEXT);
@@ -623,7 +595,7 @@ const char *savefile_get_description(const char *path) {
 	if (!check_header(f)) {
 		my_strcpy(savefile_desc, "Invalid savefile", sizeof savefile_desc);
 	} else {
-		while ((err = next_blockheader(f, &b)) == 0) {
+		while (!next_blockheader(f, &b)) {
 			if (!streq(b.name, "description")) {
 				skip_block(f, &b);
 				continue;
@@ -641,7 +613,7 @@ const char *savefile_get_description(const char *path) {
 /**
  * Load a savefile.
  */
-bool savefile_load(const char *path)
+bool savefile_load(const char *path, bool cheat_death)
 {
 	bool ok;
 	ang_file *f = file_open(path, MODE_READ, FTYPE_TEXT);
@@ -653,5 +625,19 @@ bool savefile_load(const char *path)
 	ok = try_load(f, loaders);
 	file_close(f);
 
+	if (player->chp < 0) {
+		player->is_dead = TRUE;
+	}
+
+	if (player->is_dead && cheat_death) {
+			player->is_dead = FALSE;
+			player->chp = player->mhp;
+			player->noscore |= NOSCORE_WIZARD;
+	}
+
+	/* Character is now "complete" */
+	character_generated = TRUE;
+	player->upkeep->playing = TRUE;
+
 	return ok;
 }
