@@ -1623,7 +1623,7 @@ void do_cmd_buy(struct command *cmd)
 	object_copy_amt(bought, obj, amt);
 
 	/* Ensure we have room */
-	if (!inven_carry_okay(bought)) {
+	if (bought->number > inven_carry_num(bought, FALSE)) {
 		msg("You cannot carry that many items.");
 		object_delete(&bought);
 		return;
@@ -1740,7 +1740,7 @@ void do_cmd_retrieve(struct command *cmd)
 	object_copy_amt(picked_item, obj, amt);
 
 	/* Ensure we have room */
-	if (!inven_carry_okay(picked_item)) {
+	if (picked_item->number > inven_carry_num(picked_item, FALSE)) {
 		msg("You cannot carry that many items.");
 		object_delete(&picked_item);
 		return;
