@@ -3,10 +3,10 @@
 #include "unit-test.h"
 
 #include "init.h"
-#include "player/player.h"
+#include "player.h"
 
 int setup_tests(void **state) {
-	*state = init_parse_h();
+	*state = init_parse_history();
 	return !*state;
 }
 
@@ -15,8 +15,8 @@ int teardown_tests(void *state) {
 	return 0;
 }
 
-int test_n0(void *state) {
-	enum parser_error r = parser_parse(state, "N:1:3:5:2");
+int test_chart0(void *state) {
+	enum parser_error r = parser_parse(state, "chart:1:3:5");
 	struct history_chart *c;
 	struct history_entry *e;
 
@@ -26,14 +26,14 @@ int test_n0(void *state) {
 	e = c->entries;
 	require(e);
 	eq(c->idx, 1);
-	ptreq(e->next, NULL);
+	null(e->next);
 	ptreq(e->roll, 5);
 	eq(e->isucc, 3);
 	ok;
 }
 
-int test_d0(void *state) {
-	enum parser_error r = parser_parse(state, "D:hello there");
+int test_phrase0(void *state) {
+	enum parser_error r = parser_parse(state, "phrase:hello there");
 	struct history_chart *h;
 
 	eq(r, PARSE_ERROR_NONE);
@@ -45,7 +45,7 @@ int test_d0(void *state) {
 
 const char *suite_name = "parse/h-info";
 struct test tests[] = {
-	{ "n0", test_n0 },
-	{ "d0", test_d0 },
+	{ "chart0", test_chart0 },
+	{ "phrase0", test_phrase0 },
 	{ NULL, NULL }
 };
