@@ -891,7 +891,6 @@ int edit_text(char *buffer, int buflen) {
 		/* Display on screen */
 		clear_from(HIST_INSTRUCT_ROW);
 		textblock_append(tb, buffer);
-		textblock_append(tb, "\n"); /* XXX This shouldn't be necessary */
 		textui_textblock_place(tb, area, NULL);
 
 		n_lines = textblock_calculate_lines(tb,
@@ -1096,7 +1095,7 @@ static enum birth_stage get_confirm_command(void)
 int textui_do_birth(void)
 {
 	enum birth_stage current_stage = BIRTH_RESET;
-	enum birth_stage prev;
+	enum birth_stage prev = BIRTH_BACK;
 	enum birth_stage roller = BIRTH_RESET;
 	enum birth_stage next = current_stage;
 
